@@ -52,7 +52,7 @@ class GetJson():
         print(mp3_output)
         mp3 = gTTS(text = mp3_output, lang=language)
         #Save MP3
-        mp3.save(f'{self.artist}_{self.title}.mp3')
+        mp3.save(f'Songs/{self.artist} - {self.title}(pyKaraoke).mp3')
         click.secho(
           f"MP3 file created at { sys.path[0] }/{self.artist}_{self.title}.mp3",
             fg='green')
